@@ -1,5 +1,5 @@
 package XML::RSS;
-$XML::RSS::VERSION = '1.61';
+$XML::RSS::VERSION = '1.63';
 use strict;
 use warnings;
 
@@ -332,6 +332,9 @@ sub _reset {
 
     delete $self->{_allow_multiple};
 
+    # reset empty OK to default
+    %empty_ok_elements = (enclosure => 1);
+
     my $ok_fields = $self->_get_ok_fields();
 
     my $ver_ok_fields =
@@ -664,6 +667,27 @@ sub _append_text_to_elem_struct {
     return;
 }
 
+{
+    my @_ITEM_KEYS_ELEM_STACK = ("rss", "channel", "item", "link");
+
+    sub _should_skip_item_keys_in_custom_tags {
+        my ($self, $struct, $key) = @_;
+
+        if (length $struct->{$key}) {
+            if ($self->{_internal}->{version} eq "2.0") {
+                if ($key eq "link") {
+                    my @context = $self->_parser->context();
+                    if (@context > @_ITEM_KEYS_ELEM_STACK) {
+                        return 1;
+                    }
+                }
+            }
+        }
+        return;
+    }
+}
+
+
 sub _append_struct {
     my ($self, $struct, $key, $can_be_array, $cdata) = @_;
 
@@ -682,6 +706,16 @@ sub _append_struct {
         }
     }
 
+    # Somewhat sympotamtic cure for item/link nested inside
+    # custom tags:
+    #
+    # https://github.com/shlomif/perl-XML-RSS/issues/7
+    #
+    # Thanks to @jkramer .
+    if ($self->_should_skip_item_keys_in_custom_tags($struct, $key)) {
+        return;
+    }
+
     $struct->{$key} .= $cdata;
     return;
 }
@@ -1263,6 +1297,11 @@ sub _generic_parse {
 
     $self->_parse_options($options || {});
 
+    # patch to allow a parse-time option for elements to be empty
+    foreach my $el (@{$self->_parse_options()->{'allow_empty'}}) {
+        $empty_ok_elements{$el} = 1;
+    }
+
     # Workaround to make sure that if we were defined with version => "2.0"
     # then we can still parse 1.0 and 0.9.x feeds correctly.
     if ($self->{version} eq "2.0") {
@@ -1463,13 +1502,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 XML::RSS - creates and updates RSS files
 
 =head1 VERSION
 
-version 1.61
+version 1.63
 
 =head1 SYNOPSIS
 
@@ -1800,6 +1841,17 @@ C<<< { el => $key_name, value => $value, } >>> hash-refs to gracefully
 handle duplicate items (see below). It will not affect the known modules such
 as dc ("Dublin Core").
 
+=item * allow_empty
+
+Takes an array ref of names which indicates which elements are
+allowed to be empty. So, for example, to parse feeds with custom
+fields with the form C<<< <foo bar="1" baz="2" /> >>> which have no content,
+only attributes, add:
+
+   $rss->parse($xml, { allow_empty => ['foo'] });
+
+( Added in XML::RSS v 1.63 .)
+
 =back
 
 =item parsefile ($file, \%options)
@@ -2064,36 +2116,10 @@ modify it under the same terms as Perl itself.
 
 perl(1), XML::Parser(3).
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2001 by Various.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/perl-XML-RSS/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc XML::RSS
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -2111,14 +2137,6 @@ L<https://metacpan.org/release/XML-RSS>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/XML-RSS>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -2127,22 +2145,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-RSS>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-RSS>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/XML-RSS>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -2191,4 +2193,24 @@ L<https://github.com/shlomif/perl-XML-RSS>
 
   git clone git://github.com/shlomif/perl-XML-RSS.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-XML-RSS/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2001 by Various.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
